==> adsprod-facade-2.4.4.1-sources.jar: com/bxm/adsprod/facade/ticket/adx/TicketAdx.java <==
package com.bxm.adsprod.facade.ticket.adx;

import java.io.Serializable;
import java.math.BigInteger;

/**
 * 广告券adx投放信息
 * @author allen
 * @date 2019/7/16
 * @since 1.0.0
 */
public class TicketAdx implements Serializable {

    private static final long serialVersionUID = 8471920700560060581L;

    /**
     * 加速投放
     */
    public static final short SPEED_UP = 1;

    /**
     * 匀速投放
     */
    public static final short SPEED_AVG = 2;

    /**
     * 内部人群
     */
    public static final short CROWD_SOURCE_INNER = 0;

    /**
     * 投放类型：1，App下载
     */
    public static final short PUTINTYPE_APP_DOWNLOAD = 1;

    /**
     * 投放类型：2，H5
     */
    public static final short PUTINTYPE_H5 = 2;

    /**
     * 下载类型：1，安卓；
     */
    public static final short DOWNLOAD_TYPE_ANDROID = 1;

    /**
     * 下载类型：2，IOS
     */
    public static final short DOWNLOAD_TYPE_IOS = 2;

    /**
     * 券ID
     */
    private BigInteger adTicketId;

    /**
     * 每日最多曝光次数
     */
    private Integer showMaximum;

    /**
     * 每日最多点击次数
     */
    private Integer clickMaximum;

    /**
     * 投放速度。
     * @see #SPEED_UP
     * @see #SPEED_AVG
     */
    private Short speed;

    /**
     * 人群来源。
     * @see #CROWD_SOURCE_INNER
     */
    private Short crowdSource;

    /**
     * 结算方式：1- CPC、2- CPA、4- CPM
     */
    private Short adxSettleType;

    /**
     * 单价。单位：厘
     */
    private Integer adxPrice;

    /**
     * 日限额（预算），0 表示无限额。单位：厘
     */
    private Integer adxBudgetDaily;

    /**
     * adx专员
     */
    private String adxAe;

    /**
     * 投放类型：1，App下载；2，H5
     */
    private Short adxPutinType;

    /**
     * 下载类型：默认为安卓，1，安卓；2，IOS
     */
    private Short adxDownloadType;

    /**
     * 下载安装包的AppID/包名
     */
    private String adxPackageName;

    public BigInteger getAdTicketId() {
        return adTicketId;
    }

    public void setAdTicketId(BigInteger adTicketId) {
        this.adTicketId = adTicketId;
    }

    public Integer getShowMaximum() {
        return showMaximum;
    }

    public void setShowMaximum(Integer showMaximum) {
        this.showMaximum = showMaximum;
    }

    public Integer getClickMaximum() {
        return clickMaximum;
    }

    public void setClickMaximum(Integer clickMaximum) {
        this.clickMaximum = clickMaximum;
    }

    public Short getSpeed() {
        return speed;
    }

    public void setSpeed(Short speed) {
        this.speed = speed;
    }

    public Short getCrowdSource() {
        return crowdSource;
    }

    public void setCrowdSource(Short crowdSource) {
        this.crowdSource = crowdSource;
    }

    public Short getAdxSettleType() {
        return adxSettleType;
    }

    public void setAdxSettleType(Short adxSettleType) {
        this.adxSettleType = adxSettleType;
    }

    public Integer getAdxPrice() {
        return adxPrice;
    }

    public void setAdxPrice(Integer adxPrice) {
        this.adxPrice = adxPrice;
    }

    public Integer getAdxBudgetDaily() {
        return adxBudgetDaily;
    }

    public void setAdxBudgetDaily(Integer adxBudgetDaily) {
        this.adxBudgetDaily = adxBudgetDaily;
    }

    public String getAdxAe() {
        return adxAe;
    }

    public void setAdxAe(String adxAe) {
        this.adxAe = adxAe;
    }

    public Short getAdxPutinType() {
        return adxPutinType;
    }

    public void setAdxPutinType(Short adxPutinType) {
        this.adxPutinType = adxPutinType;
    }

    public Short getAdxDownloadType() {
        return adxDownloadType;
    }

    public void setAdxDownloadType(Short adxDownloadType) {
        this.adxDownloadType = adxDownloadType;
    }

    public String getAdxPackageName() {
        return adxPackageName;
    }

    public void setAdxPackageName(String adxPackageName) {
        this.adxPackageName = adxPackageName;
    }
}

==> adsprod-facade-3.0.4-sources.jar: com/bxm/adsprod/facade/ticket/adx/TicketAdx.java <==
package com.bxm.adsprod.facade.ticket.adx;

import java.io.Serializable;
import java.math.BigInteger;

/**
 * 广告券adx投放信息
 * @author allen
 * @date 2019/7/16
 * @since 1.0.0
 */
public class TicketAdx implements Serializable {

    private static final long serialVersionUID = 8471920700560060581L;

    /**
     * 加速投放
     */
    public static final short SPEED_UP = 1;

    /**
     * 匀速投放
     */
    public static final short SPEED_AVG = 2;

    /**
     * 内部人群
     */
    public static final short CROWD_SOURCE_INNER = 0;

    /**
     * 投放类型：1，App下载
     */
    public static final short PUTINTYPE_APP_DOWNLOAD = 1;

    /**
     * 投放类型：2，H5
     */
    public static final short PUTINTYPE_H5 = 2;

    /**
     * 投放类型：3，deeplink
     */
    public static final short PUTINTYPE_DEEPLINK = 3;

    /**
     * 下载类型：1，安卓；
     */
    public static final short DOWNLOAD_TYPE_ANDROID = 1;

    /**
     * 下载类型：2，IOS
     */
    public static final short DOWNLOAD_TYPE_IOS = 2;

    /**
     * 券ID
     */
    private BigInteger adTicketId;

    /**
     * 每日最多曝光次数
     */
    private Integer showMaximum;

    /**
     * 每日最多点击次数
     */
    private Integer clickMaximum;

    /**
     * 投放速度。
     * @see #SPEED_UP
     * @see #SPEED_AVG
     */
    private Short speed;

    /**
     * 人群来源。
     * @see #CROWD_SOURCE_INNER
     */
    private Short crowdSource;

    /**
     * 结算方式：1- CPC、2- CPA、4- CPM
     */
    private Short adxSettleType;

    /**
     * 单价。单位：厘
     */
    private Integer adxPrice;

    /**
     * 日限额（预算），0 表示无限额。单位：厘
     */
    private Integer adxBudgetDaily;

    /**
     * adx专员
     */
    private String adxAe;

    /**
     * 投放类型：1，App下载；2，H5；3，deeplink
     */
    private Short adxPutinType;

    /**
     * 下载类型：默认为安卓，1，安卓；2，IOS
     */
    private Short adxDownloadType;

    /**
     * 下载安装包的AppID/包名
     */
    private String adxPackageName;

    /**
     * deeplink地址
     */
    private String deeplinkUrl;

    public BigInteger getAdTicketId() {
        return adTicketId;
    }

    public void setAdTicketId(BigInteger adTicketId) {
        this.adTicketId = adTicketId;
    }

    public Integer getShowMaximum() {
        return showMaximum;
    }

    public void setShowMaximum(Integer showMaximum) {
        this.showMaximum = showMaximum;
    }

    public Integer getClickMaximum() {
        return clickMaximum;
    }

    public void setClickMaximum(Integer clickMaximum) {
        this.clickMaximum = clickMaximum;
    }

    public Short getSpeed() {
        return speed;
    }

    public void setSpeed(Short speed) {
        this.speed = speed;
    }

    public Short getCrowdSource() {
        return crowdSource;
    }

    public void setCrowdSource(Short crowdSource) {
        this.crowdSource = crowdSource;
    }

    public Short getAdxSettleType() {
        return adxSettleType;
    }

    public void setAdxSettleType(Short adxSettleType) {
        this.adxSettleType = adxSettleType;
    }

    public Integer getAdxPrice() {
        return adxPrice;
    }

    public void setAdxPrice(Integer adxPrice) {
        this.adxPrice = adxPrice;
    }

    public Integer getAdxBudgetDaily() {
        return adxBudgetDaily;
    }

    public void setAdxBudgetDaily(Integer adxBudgetDaily) {
        this.adxBudgetDaily = adxBudgetDaily;
    }

    public String getAdxAe() {
        return adxAe;
    }

    public void setAdxAe(String adxAe) {
        this.adxAe = adxAe;
    }

    public Short getAdxPutinType() {
        return adxPutinType;
    }

    public void setAdxPutinType(Short adxPutinType) {
        this.adxPutinType = adxPutinType;
    }

    public Short getAdxDownloadType() {
        return adxDownloadType;
    }

    public void setAdxDownloadType(Short adxDownloadType) {
        this.adxDownloadType = adxDownloadType;
    }

    public String getAdxPackageName() {
        return adxPackageName;
    }

    public void setAdxPackageName(String adxPackageName) {
        this.adxPackageName = adxPackageName;
    }

    public String getDeeplinkUrl() {
        return deeplinkUrl;
    }

    public void setDeeplinkUrl(String deeplinkUrl) {
        this.deeplinkUrl = deeplinkUrl;
    }
}
